"""Common configuration constants
"""

PROJECTNAME = 'collective.salesforce.query'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'SalesforceQuery': 'collective.salesforce.query: Add SalesforceQuery',
}



"""Definition of the SalesforceQuery content type
"""

from zope.interface import implements, directlyProvides

from Products.Archetypes import atapi
from Products.ATContentTypes.content import base
from Products.ATContentTypes.content import schemata

from collective.salesforce.query import queryMessageFactory as _
from collective.salesforce.query.interfaces import ISalesforceQuery
from collective.salesforce.query.config import PROJECTNAME

SalesforceQuerySchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((

    # -*- Your Archetypes field definitions here ... -*-

    atapi.StringField(
        'datatype',
        storage=atapi.AnnotationStorage(),
        widget=atapi.SelectionWidget(
            label=_(u"Data Type"),
            description=_(u"Select data type from Salesforce"),
        ),
        required=True,
        vocabulary_factory='salesforce.datatypes',
    ),


))

# Set storage on fields copied from ATContentTypeSchema, making sure
# they work well with the python bridge properties.

SalesforceQuerySchema['title'].storage = atapi.AnnotationStorage()
SalesforceQuerySchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(SalesforceQuerySchema, moveDiscussion=False)

class SalesforceQuery(base.ATCTContent):
    """A page showing content from Salesforce"""
    implements(ISalesforceQuery)

    meta_type = "SalesforceQuery"
    schema = SalesforceQuerySchema

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')
    
    # -*- Your ATSchema to Python Property Bridges Here ... -*-
    datatype = atapi.ATFieldProperty('datatype')


atapi.registerType(SalesforceQuery, PROJECTNAME)



from zope import schema
from zope.interface import Interface

from zope.app.container.constraints import contains
from zope.app.container.constraints import containers

from collective.salesforce.query import queryMessageFactory as _

class ISalesforceQuery(Interface):
    """A page showing content from Salesforce"""
    
    # -*- schema definition goes here -*-
    datatype = schema.TextLine(
        title=_(u"Data Type"), 
        required=True,
        description=_(u"Select data type from Salesforce"),
    )




# -*- coding: utf-8 -*-
from zope.interface import implements, Interface

from Products.Five import BrowserView
from Products.CMFCore.utils import getToolByName

from collective.salesforce.query import queryMessageFactory as _


class ISalesforceQueryView(Interface):
    """
    SalesforceQueryView view interface
    """

    def getHeaders():
        """
        get all fields from the given data type
        """

    def getEntries():
        """
        get all content for the given datatype
        """

    def test():
        """method that does the same as test on old page templates"""

class SalesforceQueryView(BrowserView):
    """
    SalesforceQueryView browser view
    """
    implements(ISalesforceQueryView)

    def __init__(self, context, request):
        self.context = context
        self.request = request
        

    @property
    def salesforce_tool(self):
        return getToolByName(self.context, 'portal_salesforcebaseconnector')
        
    @property
    def portal_catalog(self):
        return getToolByName(self.context, 'portal_catalog')

    @property
    def portal(self):
        return getToolByName(self.context, 'portal_url').getPortalObject()

    def getHeaders(self):
        """
        get all fields from the given data type
        """
        result = self.salesforce_tool.describeSObjects([self.context.datatype,])[0]
        fields = result.__dict__['fields'].keys()
        return fields

    def getEntries(self, headers):
        """
        get all content for the given datatype
        """
        results = self.salesforce_tool.query(headers,self.context.datatype)
        return results['records']


    def test(self, condition, true_value, false_value):
        """
        method that does the same as test on old page templates
        """

        if condition:
            return true_value
        else:
            return false_value
